@@ -10,7 +10,7 @@ use Scalar::Util qw(blessed);
 use UNIVERSAL::DOES;
 
 BEGIN {
-  our $VERSION = '2.014_001'; # version template
+  our $VERSION = '2.015'; # version template
 }
 use List::Util qw(first);
 use Treex::PML::Instance::Common qw(:diagnostics :constants);
@@ -18,14 +18,6 @@ use Treex::PML::Schema;
 use Treex::PML::IO qw(open_backend close_backend rename_uri);
 use Encode;
 
-
-my $BUG;
-eval {
-    require XML::LibXSLT;
-    $BUG = grep 10127 == $_, XML::LibXSLT::LIBXSLT_VERSION(),
-                             XML::LibXSLT::LIBXSLT_RUNTIME_VERSION();
-};
-
 my (
   %handlers,
   %src,
@@ -253,7 +245,7 @@ sub save {
   die $@ if $@;
 
   if ($xsl_source and $out_xsl_href) {
-    die "Buggy libxslt version 10127\n" if $BUG;
+    die "Buggy libxslt version 10127\n" if XSLT_BUG;
     my $xslt = XML::LibXSLT->new;
     my $params = $out_xsl->content;
     my %params;
